#include "../../include/freenet/boardlistxml.h"

#ifdef XMEM
	#include <xmem.h>
#endif

BoardListXML::BoardListXML()
{
	Initialize();
}

void BoardListXML::AddBoard(const std::string &name, const std::string &description)
{
	if(name!="" && description!="")
	{
		m_boards.push_back(board(name,description));
	}
}

const std::string BoardListXML::GetDescription(const long index)
{
	if(index>=0 && index<GetCount())
	{
		return m_boards[index].m_description;
	}
	else
	{
		return "";
	}
}

const std::string BoardListXML::GetName(const long index)
{
	if(index>=0 && index<GetCount())
	{
		return m_boards[index].m_name;
	}
	else
	{
		return "";
	}
}

std::string BoardListXML::GetXML()
{
	TiXmlDocument td;
	TiXmlDeclaration *tdec=new TiXmlDeclaration("1.0","UTF-8","");
	TiXmlElement *tid;
	TiXmlPrinter tp;

	td.LinkEndChild(tdec);
	tid=new TiXmlElement("BoardList");
	td.LinkEndChild(tid);

	for(std::vector<board>::iterator i=m_boards.begin(); i!=m_boards.end(); i++)
	{
		TiXmlElement *tr=new TiXmlElement("Board");
		tid->LinkEndChild(tr);
		tr->LinkEndChild(XMLCreateCDATAElement("Name",(*i).m_name));
		tr->LinkEndChild(XMLCreateCDATAElement("Description",(*i).m_description));
	}

	td.Accept(&tp);
	return std::string(tp.CStr());
}

void BoardListXML::Initialize()
{
	m_boards.clear();
}

const bool BoardListXML::ParseXML(const std::string &xml)
{
	std::string name;
	std::string description;
	TiXmlDocument td;
	td.Parse(xml.c_str());

	if(!td.Error())
	{
		TiXmlText *txt;
		TiXmlHandle hnd(&td);
		TiXmlNode *node;

		Initialize();

		node=hnd.FirstChild("BoardList").FirstChild("Board").ToElement();
		while(node)
		{
			name="";
			description="";

			TiXmlHandle hnd2(node);
			txt=hnd2.FirstChild("Name").FirstChild().ToText();
			if(txt)
			{
				name=txt->ValueStr();
			}
			txt=hnd2.FirstChild("Description").FirstChild().ToText();
			if(txt)
			{
				description=txt->ValueStr();
			}

			if(name!="" && description!="")
			{
				m_boards.push_back(board(name,description));
			}
			
			node=node->NextSibling("Board");
		}
		return true;

	}
	else
	{
		return false;
	}
}
